"""
backend_sdk_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_sdk_types import BackendSdkTypes
class BackendSdkResponse(BaseModel):
    types: Optional[BackendSdkTypes] = Field(default=None, alias="types")
    pass



"""
SystemMetaTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .common_message_exception import CommonMessageException
from .passthru import Passthru
from .system_about import SystemAbout
from .system_health_check import SystemHealthCheck
from .system_o_auth_configuration import SystemOAuthConfiguration
from .system_route import SystemRoute
from .system_schema import SystemSchema

class SystemMetaTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get_schema(self, name: str) -> SystemSchema:
        try:
            path_params = {}
            path_params["name"] = name

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/system/schema/:name", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemSchema.model_validate_json(json_data=response.content)

            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 410:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_routes(self) -> SystemRoute:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/system/route", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemRoute.model_validate_json(json_data=response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_o_auth_configuration(self) -> SystemOAuthConfiguration:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/system/oauth-authorization-server", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemOAuthConfiguration.model_validate_json(json_data=response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_health(self) -> SystemHealthCheck:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/system/health", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemHealthCheck.model_validate_json(json_data=response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_debug(self, payload: Passthru) -> Passthru:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/system/debug", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return Passthru.model_validate_json(json_data=response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_about(self) -> SystemAbout:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/system/about", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemAbout.model_validate_json(json_data=response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
BackendMarketplaceAppTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .marketplace_app import MarketplaceApp
from .marketplace_app_collection import MarketplaceAppCollection
from .marketplace_install import MarketplaceInstall
from .marketplace_message import MarketplaceMessage
from .marketplace_message_exception import MarketplaceMessageException

class BackendMarketplaceAppTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def upgrade(self, user: str, name: str) -> MarketplaceMessage:
        try:
            path_params = {}
            path_params["user"] = user
            path_params["name"] = name

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/marketplace/app/:user/:name", path_params)

            headers = {}

            response = self.http_client.put(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return MarketplaceMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 401:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 404:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 410:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 500:
                raise MarketplaceMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get(self, user: str, name: str) -> MarketplaceApp:
        try:
            path_params = {}
            path_params["user"] = user
            path_params["name"] = name

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/marketplace/app/:user/:name", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return MarketplaceApp.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 404:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 410:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 500:
                raise MarketplaceMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def install(self, payload: MarketplaceInstall) -> MarketplaceMessage:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/marketplace/app", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return MarketplaceMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 401:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 500:
                raise MarketplaceMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_all(self, start_index: int, query: str) -> MarketplaceAppCollection:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["query"] = query

            query_struct_names = []

            url = self.parser.url("/backend/marketplace/app", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return MarketplaceAppCollection.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise MarketplaceMessageException(response.content)
            if response.status_code == 500:
                raise MarketplaceMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
backend_generator_index_providers automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_generator_index_provider import BackendGeneratorIndexProvider
class BackendGeneratorIndexProviders(BaseModel):
    providers: Optional[List[BackendGeneratorIndexProvider]] = Field(default=None, alias="providers")
    pass



"""
backend_action_execute_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_action_execute_response_headers import BackendActionExecuteResponseHeaders
from .backend_action_execute_response_body import BackendActionExecuteResponseBody
class BackendActionExecuteResponse(BaseModel):
    status_code: Optional[int] = Field(default=None, alias="statusCode")
    headers: Optional[BackendActionExecuteResponseHeaders] = Field(default=None, alias="headers")
    body: Optional[BackendActionExecuteResponseBody] = Field(default=None, alias="body")
    pass



"""
backend_account_change_password automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendAccountChangePassword(BaseModel):
    old_password: Optional[str] = Field(default=None, alias="oldPassword")
    new_password: Optional[str] = Field(default=None, alias="newPassword")
    verify_password: Optional[str] = Field(default=None, alias="verifyPassword")
    pass



"""
backend_action_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_action_index_entry import BackendActionIndexEntry
class BackendActionIndex(BaseModel):
    actions: Optional[List[BackendActionIndexEntry]] = Field(default=None, alias="actions")
    pass



"""
backend_scope automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_scope_operation import BackendScopeOperation
from .common_metadata import CommonMetadata
class BackendScope(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    description: Optional[str] = Field(default=None, alias="description")
    operations: Optional[List[BackendScopeOperation]] = Field(default=None, alias="operations")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass



"""
backend_database_table_column automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendDatabaseTableColumn(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    type: Optional[str] = Field(default=None, alias="type")
    length: Optional[int] = Field(default=None, alias="length")
    precision: Optional[int] = Field(default=None, alias="precision")
    scale: Optional[int] = Field(default=None, alias="scale")
    unsigned: Optional[bool] = Field(default=None, alias="unsigned")
    fixed: Optional[bool] = Field(default=None, alias="fixed")
    not_null: Optional[bool] = Field(default=None, alias="notNull")
    auto_increment: Optional[bool] = Field(default=None, alias="autoIncrement")
    default: Optional[Any] = Field(default=None, alias="default")
    comment: Optional[str] = Field(default=None, alias="comment")
    pass



"""
system_about_apps automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class SystemAboutApps(Dict[str, str]):
    @classmethod
    def __get_pydantic_core_schema__(cls, source_type: Any, handler: GetCoreSchemaHandler) -> CoreSchema:
        return core_schema.dict_schema(handler.generate_schema(str), handler.generate_schema(str))



"""
consumer_user_account automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .consumer_user_plan import ConsumerUserPlan
from .common_metadata import CommonMetadata
class ConsumerUserAccount(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    plan_id: Optional[int] = Field(default=None, alias="planId")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    email: Optional[str] = Field(default=None, alias="email")
    points: Optional[int] = Field(default=None, alias="points")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    plans: Optional[List[ConsumerUserPlan]] = Field(default=None, alias="plans")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass



"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .consumer_authorize_response_token import ConsumerAuthorizeResponseToken
class ConsumerAuthorizeResponse(BaseModel):
    type: Optional[str] = Field(default=None, alias="type")
    token: Optional[ConsumerAuthorizeResponseToken] = Field(default=None, alias="token")
    code: Optional[str] = Field(default=None, alias="code")
    redirect_uri: Optional[str] = Field(default=None, alias="redirectUri")
    pass



"""
BackendDatabaseTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .backend_database_connections import BackendDatabaseConnections
from .backend_database_row import BackendDatabaseRow
from .backend_database_rows import BackendDatabaseRows
from .backend_database_table import BackendDatabaseTable
from .backend_database_tables import BackendDatabaseTables
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendDatabaseTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def delete_row(self, connection_id: str, table_name: str, id: str) -> CommonMessage:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name
            path_params["id"] = id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name/rows/:id", path_params)

            headers = {}

            response = self.http_client.delete(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def update_row(self, connection_id: str, table_name: str, id: str, payload: BackendDatabaseRow) -> CommonMessage:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name
            path_params["id"] = id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name/rows/:id", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.put(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def create_row(self, connection_id: str, table_name: str, payload: BackendDatabaseRow) -> CommonMessage:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name/rows", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_row(self, connection_id: str, table_name: str, id: str) -> BackendDatabaseRow:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name
            path_params["id"] = id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name/rows/:id", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendDatabaseRow.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_rows(self, connection_id: str, table_name: str, start_index: int, count: int, filter_by: str, filter_op: str, filter_value: str, sort_by: str, sort_order: str, columns: str) -> BackendDatabaseRows:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["filterBy"] = filter_by
            query_params["filterOp"] = filter_op
            query_params["filterValue"] = filter_value
            query_params["sortBy"] = sort_by
            query_params["sortOrder"] = sort_order
            query_params["columns"] = columns

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name/rows", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendDatabaseRows.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def delete_table(self, connection_id: str, table_name: str) -> CommonMessage:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name", path_params)

            headers = {}

            response = self.http_client.delete(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def update_table(self, connection_id: str, table_name: str, payload: BackendDatabaseTable) -> CommonMessage:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.put(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def create_table(self, connection_id: str, payload: BackendDatabaseTable) -> CommonMessage:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_table(self, connection_id: str, table_name: str) -> BackendDatabaseTable:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id
            path_params["table_name"] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id/:table_name", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendDatabaseTable.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_tables(self, connection_id: str) -> BackendDatabaseTables:
        try:
            path_params = {}
            path_params["connection_id"] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database/:connection_id", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendDatabaseTables.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_connections(self) -> BackendDatabaseConnections:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/database", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendDatabaseConnections.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
backend_audit automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .backend_app import BackendApp
from .backend_user import BackendUser
from .backend_audit_object import BackendAuditObject
class BackendAudit(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app: Optional[BackendApp] = Field(default=None, alias="app")
    user: Optional[BackendUser] = Field(default=None, alias="user")
    event: Optional[str] = Field(default=None, alias="event")
    ip: Optional[str] = Field(default=None, alias="ip")
    message: Optional[str] = Field(default=None, alias="message")
    content: Optional[BackendAuditObject] = Field(default=None, alias="content")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass



"""
consumer_payment_checkout_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class ConsumerPaymentCheckoutRequest(BaseModel):
    plan_id: Optional[int] = Field(default=None, alias="planId")
    return_url: Optional[str] = Field(default=None, alias="returnUrl")
    pass



"""
system_about_link automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class SystemAboutLink(BaseModel):
    rel: Optional[str] = Field(default=None, alias="rel")
    href: Optional[str] = Field(default=None, alias="href")
    pass



"""
consumer_authorize_meta automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .consumer_scope import ConsumerScope
class ConsumerAuthorizeMeta(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    url: Optional[str] = Field(default=None, alias="url")
    scopes: Optional[List[ConsumerScope]] = Field(default=None, alias="scopes")
    pass



"""
backend_action_execute_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_action_execute_request_body import BackendActionExecuteRequestBody
class BackendActionExecuteRequest(BaseModel):
    method: Optional[str] = Field(default=None, alias="method")
    uri_fragments: Optional[str] = Field(default=None, alias="uriFragments")
    parameters: Optional[str] = Field(default=None, alias="parameters")
    headers: Optional[str] = Field(default=None, alias="headers")
    body: Optional[BackendActionExecuteRequestBody] = Field(default=None, alias="body")
    pass



"""
backend_connection_introspection_entity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_connection_introspection_entity_row import BackendConnectionIntrospectionEntityRow
class BackendConnectionIntrospectionEntity(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    headers: Optional[List[str]] = Field(default=None, alias="headers")
    rows: Optional[List[BackendConnectionIntrospectionEntityRow]] = Field(default=None, alias="rows")
    pass



"""
backend_statistic_count automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class BackendStatisticCount(BaseModel):
    count: Optional[int] = Field(default=None, alias="count")
    from_: Optional[datetime.datetime] = Field(default=None, alias="from")
    to: Optional[datetime.datetime] = Field(default=None, alias="to")
    pass



"""
BackendTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .backend_account_tag import BackendAccountTag
from .backend_action_tag import BackendActionTag
from .backend_app_tag import BackendAppTag
from .backend_audit_tag import BackendAuditTag
from .backend_backup_tag import BackendBackupTag
from .backend_category_tag import BackendCategoryTag
from .backend_config_tag import BackendConfigTag
from .backend_connection_tag import BackendConnectionTag
from .backend_cronjob_tag import BackendCronjobTag
from .backend_dashboard_tag import BackendDashboardTag
from .backend_database_tag import BackendDatabaseTag
from .backend_event_tag import BackendEventTag
from .backend_generator_tag import BackendGeneratorTag
from .backend_identity_tag import BackendIdentityTag
from .backend_log_tag import BackendLogTag
from .backend_marketplace_tag import BackendMarketplaceTag
from .backend_operation_tag import BackendOperationTag
from .backend_page_tag import BackendPageTag
from .backend_plan_tag import BackendPlanTag
from .backend_rate_tag import BackendRateTag
from .backend_role_tag import BackendRoleTag
from .backend_schema_tag import BackendSchemaTag
from .backend_scope_tag import BackendScopeTag
from .backend_sdk_tag import BackendSdkTag
from .backend_statistic_tag import BackendStatisticTag
from .backend_tenant_tag import BackendTenantTag
from .backend_test_tag import BackendTestTag
from .backend_token_tag import BackendTokenTag
from .backend_transaction_tag import BackendTransactionTag
from .backend_trash_tag import BackendTrashTag
from .backend_user_tag import BackendUserTag
from .backend_webhook_tag import BackendWebhookTag

class BackendTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def webhook(self) -> BackendWebhookTag:
        return BackendWebhookTag(
            self.http_client,
            self.parser
        )

    def user(self) -> BackendUserTag:
        return BackendUserTag(
            self.http_client,
            self.parser
        )

    def trash(self) -> BackendTrashTag:
        return BackendTrashTag(
            self.http_client,
            self.parser
        )

    def transaction(self) -> BackendTransactionTag:
        return BackendTransactionTag(
            self.http_client,
            self.parser
        )

    def token(self) -> BackendTokenTag:
        return BackendTokenTag(
            self.http_client,
            self.parser
        )

    def test(self) -> BackendTestTag:
        return BackendTestTag(
            self.http_client,
            self.parser
        )

    def tenant(self) -> BackendTenantTag:
        return BackendTenantTag(
            self.http_client,
            self.parser
        )

    def statistic(self) -> BackendStatisticTag:
        return BackendStatisticTag(
            self.http_client,
            self.parser
        )

    def sdk(self) -> BackendSdkTag:
        return BackendSdkTag(
            self.http_client,
            self.parser
        )

    def scope(self) -> BackendScopeTag:
        return BackendScopeTag(
            self.http_client,
            self.parser
        )

    def schema_(self) -> BackendSchemaTag:
        return BackendSchemaTag(
            self.http_client,
            self.parser
        )

    def operation(self) -> BackendOperationTag:
        return BackendOperationTag(
            self.http_client,
            self.parser
        )

    def role(self) -> BackendRoleTag:
        return BackendRoleTag(
            self.http_client,
            self.parser
        )

    def rate(self) -> BackendRateTag:
        return BackendRateTag(
            self.http_client,
            self.parser
        )

    def plan(self) -> BackendPlanTag:
        return BackendPlanTag(
            self.http_client,
            self.parser
        )

    def page(self) -> BackendPageTag:
        return BackendPageTag(
            self.http_client,
            self.parser
        )

    def marketplace(self) -> BackendMarketplaceTag:
        return BackendMarketplaceTag(
            self.http_client,
            self.parser
        )

    def log(self) -> BackendLogTag:
        return BackendLogTag(
            self.http_client,
            self.parser
        )

    def identity(self) -> BackendIdentityTag:
        return BackendIdentityTag(
            self.http_client,
            self.parser
        )

    def generator(self) -> BackendGeneratorTag:
        return BackendGeneratorTag(
            self.http_client,
            self.parser
        )

    def backup(self) -> BackendBackupTag:
        return BackendBackupTag(
            self.http_client,
            self.parser
        )

    def event(self) -> BackendEventTag:
        return BackendEventTag(
            self.http_client,
            self.parser
        )

    def database(self) -> BackendDatabaseTag:
        return BackendDatabaseTag(
            self.http_client,
            self.parser
        )

    def dashboard(self) -> BackendDashboardTag:
        return BackendDashboardTag(
            self.http_client,
            self.parser
        )

    def cronjob(self) -> BackendCronjobTag:
        return BackendCronjobTag(
            self.http_client,
            self.parser
        )

    def connection(self) -> BackendConnectionTag:
        return BackendConnectionTag(
            self.http_client,
            self.parser
        )

    def config(self) -> BackendConfigTag:
        return BackendConfigTag(
            self.http_client,
            self.parser
        )

    def category(self) -> BackendCategoryTag:
        return BackendCategoryTag(
            self.http_client,
            self.parser
        )

    def audit(self) -> BackendAuditTag:
        return BackendAuditTag(
            self.http_client,
            self.parser
        )

    def app(self) -> BackendAppTag:
        return BackendAppTag(
            self.http_client,
            self.parser
        )

    def action(self) -> BackendActionTag:
        return BackendActionTag(
            self.http_client,
            self.parser
        )

    def account(self) -> BackendAccountTag:
        return BackendAccountTag(
            self.http_client,
            self.parser
        )





"""
system_about automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .system_about_apps import SystemAboutApps
from .system_about_link import SystemAboutLink
class SystemAbout(BaseModel):
    api_version: Optional[str] = Field(default=None, alias="apiVersion")
    title: Optional[str] = Field(default=None, alias="title")
    description: Optional[str] = Field(default=None, alias="description")
    terms_of_service: Optional[str] = Field(default=None, alias="termsOfService")
    contact_name: Optional[str] = Field(default=None, alias="contactName")
    contact_url: Optional[str] = Field(default=None, alias="contactUrl")
    contact_email: Optional[str] = Field(default=None, alias="contactEmail")
    license_name: Optional[str] = Field(default=None, alias="licenseName")
    license_url: Optional[str] = Field(default=None, alias="licenseUrl")
    payment_currency: Optional[str] = Field(default=None, alias="paymentCurrency")
    categories: Optional[List[str]] = Field(default=None, alias="categories")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    apps: Optional[SystemAboutApps] = Field(default=None, alias="apps")
    links: Optional[List[SystemAboutLink]] = Field(default=None, alias="links")
    pass
